@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.510';
+our $VERSION = '1.512';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -49,7 +49,7 @@ sub DESTROY {
 }
 
 
-sub __defaults {
+sub __defaults {        #hae
     my ( $self ) = @_;
     my $prompt = defined $self->{wantarray} ? 'Your choice:' : 'Close with ENTER';
     return {
@@ -87,7 +87,7 @@ sub __undef_to_defaults {
 }
 
 
-sub __valid_options {
+sub __valid_options {       #hae
     return {
         beep            => '[ 0 1 ]',
         clear_screen    => '[ 0 1 ]',
@@ -138,13 +138,6 @@ sub __validate_and_add_options {
             if ( $key eq 'lf' ) {
                 croak "$sub $key => too many array elements." if @{$opt->{$key}} > 2;
             }
-            else {
-                if ( defined $self->{orig_list} ) {
-                    for ( @{$opt->{$key}} ) {
-                        croak "$sub $key => $_ out of range." if $_ > $#{$self->{orig_list}};
-                    }
-                }
-            }
         }
         elsif ( $valid->{$key} eq 'Str' ) {
             croak "$sub $key => references are not valid values." if ref $opt->{$key} ne '';
@@ -191,9 +184,15 @@ sub __get_key {
 }
 
 
-sub config {
+sub config {            # DEPRECATED 10.02.2018
     my $self = shift;
     my ( $opt ) = @_;
+    ###################
+    print 'The method "config" is deprecated and will be removed with the next release.' . "\n";
+    print 'Continue with ENTER ';
+    my $p = <STDIN>;
+    print "\n";
+    ##################
     croak "config: called with " . @_ . " arguments - 0 or 1 arguments expected" if @_ > 1;
     if ( defined $opt ) {
         croak "config: the argument must be a HASH reference" if ref $opt ne 'HASH';
@@ -202,7 +201,7 @@ sub config {
 }
 
 
-sub choose {
+sub choose {      #hae
     if ( ref $_[0] ne 'Term::Choose' ) {
         return Term::Choose->new()->__choose( @_ );
     }
@@ -233,13 +232,12 @@ sub __choose {
     }
     # ###
 
-    $self->{orig_list} = $orig_list_ref;
     local $\ = undef;
     local $, = undef;
     local $| = 1;
     $self->{wantarray} = wantarray;
     $self->__undef_to_defaults();
-    $self->__copy_orig_list();
+    $self->__copy_orig_list( $orig_list_ref );
     $self->__length_longest(); #
     $self->{col_width} = $self->{length_longest} + $self->{pad};
     local $SIG{'INT'} = sub {
@@ -261,7 +259,7 @@ sub __choose {
             if ( $self->{ll} ) {
                 return -1;
             }
-            $self->__copy_orig_list();
+            $self->__copy_orig_list( $orig_list_ref );
             $self->{default} = $self->{rc2idx}[$self->{pos}[ROW]][$self->{pos}[COL]];
             if ( $self->{wantarray} && @{$self->{marked}} ) {
                 $self->{mark} = $self->__marked_rc2idx();
@@ -275,6 +273,9 @@ sub __choose {
         }
         next GET_KEY if $key == NEXT_get_key;
         next GET_KEY if $key == KEY_Tilde;
+        if ( exists $ENV{TC_RESET_AUTO_UP} ) {
+            $ENV{TC_RESET_AUTO_UP} = 1 if $key != KEY_ENTER;
+        }
 
         # $self->{rc2idx} holds the new list (AoA) formatted in "__size_and_layout" appropriate to the chosen layout.
         # $self->{rc2idx} does not hold the values directly but the respective list indexes from the original list.
@@ -508,11 +509,11 @@ sub __choose {
                 $self->{marked}[$self->{pos}[ROW]][$self->{pos}[COL]] = 1;
                 my $chosen = $self->__marked_rc2idx();
                 $self->__reset_term( 1 );
-                return $index ? @$chosen : @{$self->{orig_list}}[@$chosen];
+                return $index ? @$chosen : @{$orig_list_ref}[@$chosen];
             }
             else {
                 my $i = $self->{rc2idx}[$self->{pos}[ROW]][$self->{pos}[COL]];
-                my $chosen = $index ? $i : $self->{orig_list}[$i];
+                my $chosen = $index ? $i : $orig_list_ref->[$i];
                 $self->__reset_term( 1 );
                 return $chosen;
             }
@@ -571,8 +572,10 @@ sub __choose {
 
 sub __marked_idx2rc {
     my ( $self, $list_of_indexes, $boolean ) = @_;
+    my $last_list_idx = $#{$self->{list}};
     if ( $self->{current_layout} == 3 ) {
         for my $idx ( @$list_of_indexes ) {
+            next if $idx > $last_list_idx;
             $self->{marked}[$idx][0] = $boolean;
         }
         return;
@@ -581,6 +584,7 @@ sub __marked_idx2rc {
     my $cols_per_row = @{$self->{rc2idx}[0]};
     if ( $self->{order} == 0 ) {
         for my $idx ( @$list_of_indexes ) {
+            next if $idx > $last_list_idx;
             $row = int( $idx / $cols_per_row );
             $col = $idx % $cols_per_row;
             $self->{marked}[$row][$col] = $boolean;
@@ -590,6 +594,7 @@ sub __marked_idx2rc {
         my $rows_per_col = @{$self->{rc2idx}};
         my $end_last_full_col = $rows_per_col * ( $self->{rest} || $cols_per_row );
         for my $idx ( @$list_of_indexes ) {
+            next if $idx > $last_list_idx;
             if ( $idx <= $end_last_full_col ) {
                 $row = $idx % $rows_per_col;
                 $col = int( $idx / $rows_per_col );
@@ -636,9 +641,9 @@ sub __beep {
 }
 
 
-sub __copy_orig_list {
-    my ( $self ) = @_;
-    $self->{list} = [ @{$self->{orig_list}} ];
+sub __copy_orig_list {      #hae
+    my ( $self, $orig_list_ref ) = @_;
+    $self->{list} = [ @$orig_list_ref ];
     if ( $self->{ll} ) {
         for ( @{$self->{list}} ) {
             $_ = $self->{undef} if ! defined $_;
@@ -916,7 +921,7 @@ sub __wr_screen {
 }
 
 
-sub __wr_cell {
+sub __wr_cell {     # hae
     my( $self, $row, $col ) = @_;
     my $is_current_pos = $row == $self->{pos}[ROW] && $col == $self->{pos}[COL];
     my $idx = $self->{rc2idx}[$row][$col];
@@ -950,12 +955,12 @@ sub __wr_cell {
 # __copy_orig_list, __wr_cell, __print_columns, __unicode_trim
 
 
-sub __print_columns {
+sub __print_columns {       #hae
     #my $self = $_[0];
     print_columns( $_[1] );
 }
 
-sub __unicode_trim {
+sub __unicode_trim {        #hae
     #my $self = $_[0];
     cut_to_printwidth( $_[1], $_[2] );
 }
@@ -1073,7 +1078,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.510
+Version 1.512
 
 =cut
 
@@ -1104,7 +1109,6 @@ Object-oriented interface:
     my $choice = $new->choose( $array_ref );                       # single choice
     print "$choice\n";
 
-    $new->config( { justify => 1 } );
     my @choices = $new->choose( [ 1 .. 100 ] );                    # multiple choice
     print "@choices\n";
 
@@ -1135,7 +1139,7 @@ To set the different options it can be passed a reference to a hash as an option
 
 For detailed information about the options see L</OPTIONS>.
 
-=head2 config
+=head2 config DEPRECATED
 
     $new->config( \%options );
 
@@ -1458,7 +1462,7 @@ See C<INITIAL_TAB> and C<SUBSEQUENT_TAB> in L<Text::LineFold>.
 
 (default: undefined)
 
-=head2 ll UPDATE
+=head2 ll
 
 If all elements have the same length, the length can be passed with this option.
 
@@ -1492,7 +1496,8 @@ Allowed values: 1 or greater
 =head2 mark
 
 I<mark> expects as its value a reference to an array. The elements of the array are list indexes. C<choose> preselects
-the list-elements correlating to these indexes. This option has only meaning in list context.
+the list-elements correlating to these indexes. This option has only meaning in list context. Elements greater than the
+last index of the list are ignored.
 
 (default: undefined)
 
@@ -1545,10 +1550,11 @@ of L<Win32::Console>.
 
 =head2 no_spacebar
 
-I<no_spacebar> expects as its value a reference to an array. The elements of the array are indexes of choices which
+I<no_spacebar> expects as its value a reference to an array. The elements of the array are indexes of the list which
 should not be markable with the C<SpaceBar> or with the right mouse key. This option has only meaning in list context.
 If an element is preselected with the option I<mark> and also marked as not selectable with the option I<no_spacebar>,
-the user can not remove the preselection of this element.
+the user can not remove the preselection of this element. I<no_spacebar> elements greater than the last index of the
+list are ignored.
 
 (default: undefined)
 
@@ -1594,29 +1600,13 @@ default: "<undef>"
 
 =head2 croak
 
-C<new|config|choose> dies if
-
-=over
-
-=item * passed an invalid number of arguments.
-
-=item * passed an invalid argument.
-
-=item * passed an invalid option name.
-
-=item * passed an invalid option value.
-
-=back
+C<new|config|choose> dies if passed invalid arguments.
 
 =head2 carp
 
-=over
-
-=item * If after pressing a key L<Term::ReadKey>::ReadKey returns C<undef> C<choose> warns with C<EOT: $!> and returns
+If after pressing a key L<Term::ReadKey>::ReadKey returns C<undef> C<choose> warns with C<EOT: $!> and returns
 I<undef> or an empty list in list context.
 
-=back
-
 =head1 REQUIREMENTS
 
 =head2 Perl version
