@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.510';
+our $VERSION = '1.512';
 
 use Exporter qw( import );
 
@@ -98,13 +98,14 @@ sub line_fold {
     if ( $string !~ /\n/ && print_columns( $init_tab . $string ) <= $avail_width ) {
         return $init_tab . $string;
     }
-    my $trailer = '';
-    if ( $string =~ /(\n+)\z/ ) {
-        $trailer = $1;
-    }
+#    my $trailer = '';
+#    if ( $string =~ /(\n+)\z/ ) {
+#        $trailer = $1;
+#    }
     my @paragraph;
 
-    for my $row ( split "\n", $string ) {
+#    for my $row ( split "\n", $string ) {
+    for my $row ( split "\n", $string, -1 ) { # -1 to keep trailing empty fields
         my @lines;
         $row =~ s/\s+\z//;
         my @words = split( /(?<=\S)(?=\s)/, $row );
@@ -137,7 +138,8 @@ sub line_fold {
         }
         push( @paragraph, join( "\n", @lines ) );
     }
-    return join( "\n", @paragraph ) . $trailer;
+#    return join( "\n", @paragraph ) . $trailer;
+    return join( "\n", @paragraph );
 }
 
 
